summaryrefslogtreecommitdiffstats
path: root/libtdegames/highscore/khighscore.h
diff options
context:
space:
mode:
Diffstat (limited to 'libtdegames/highscore/khighscore.h')
-rw-r--r--libtdegames/highscore/khighscore.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/libtdegames/highscore/khighscore.h b/libtdegames/highscore/khighscore.h
index 81ee562e..4cf5778c 100644
--- a/libtdegames/highscore/khighscore.h
+++ b/libtdegames/highscore/khighscore.h
@@ -26,7 +26,7 @@
#include <tqstring.h>
#include <tqobject.h>
#include <kdemacros.h>
-class KConfig;
+class TDEConfig;
class KFileLock;
class KRawConfig;
class KHighscorePrivate;
@@ -39,7 +39,7 @@ class KHighscorePrivate;
* --enable-highscore-dir=/var/games) and a theoretically unlimited number of
* entries.
*
* You can specify different "keys" for an entry - just like the KConfig
* keys. But it will be prefixed with the number of the entry. For example you
* will probably use something like this to save the name of the player on the
* top of the list (ie the winner):
@@ -51,7 +51,7 @@ class KHighscorePrivate;
* entry. I recommend to use "1", as several convenience methods use this.
*
* You can also specify different groups using setHighscoreGroup. Just
* like the keys mentioned above the groups behave like groups in KConfig
* but are prefixed with "KHighscore_". The default group is just "KHighscore".
* You might use this e.g. to create different highscore tables like
* \code
@@ -164,7 +164,7 @@ public:
/**
* @param entry The number of the entry / the placing of the player
* @param key A key for this entry. E.g. "name" for the name of the
* player. Nearly the same as the usual keys in KConfig - but they
* are prefixed with the entry number
* @param value The value of this entry
**/
@@ -179,7 +179,7 @@ public:
/**
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
* See KConfigBase documentation for allowed TQVariant::Type.
**/
void writeEntry(int entry, const TQString& key, const TQVariant &value);
@@ -187,7 +187,7 @@ public:
* Reads an entry from the highscore table.
* @param entry The number of the entry / the placing to be read
* @param key The key of the entry. E.g. "name" for the name of the
* player. Nearly the same as the usual keys in KConfig - but they
* are prefixed with the entry number
* @param pDefault This will be used as default value if the key+pair
* entry can't be found.
@@ -200,7 +200,7 @@ public:
* Read a numeric value.
* @param entry The number of the entry / the placing to be read
* @param key The key of the entry. E.g. "name" for the name of the
* player. Nearly the same as the usual keys in KConfig - but they
* are prefixed with the entry number
* @param pDefault This will be used as default value if the key+pair
* entry can't be found.
@@ -211,7 +211,7 @@ public:
/**
* Read a TQVariant entry.
* See KConfigBase documentation for allowed TQVariant::Type.
*
* @return the value of this entry+key pair or pDefault if the entry+key
* pair doesn't exist or
@@ -234,7 +234,7 @@ public:
* readEntry(i, key) where i is from 1 to 20. Note that this function
* depends on "1" as the first entry!
* @param key The key of the entry. E.g. "name" for the name of the
* player. Nearly the same as the usual keys in KConfig - but they
* are prefixed with the entry number
* @param lastEntry the last entry which will be includes into the list.
* 1 will include a list with maximal 1 entry - 20 a list with maximal
@@ -250,7 +250,7 @@ public:
* way of calling writeEntry(i, key, list[i]) from i = 1 to
* list.count()
* @param key A key for the entry. E.g. "name" for the name of the
* player. Nearly the same as the usual keys in KConfig - but they
* are prefixed with the entry number
* @param list The list of values
**/
@@ -288,17 +288,17 @@ public:
protected:
/**
* @return A groupname to be used in KConfig. Used internally to
* prefix the value from highscoreGroup() with "KHighscore_"
**/
TQString group() const;
/**
* @return A pointer to the KConfig object to be used. This is
* either kapp->config() (default) or a KSimpleConfig object for
* a system-wide highscore file.
**/
- KConfig* config() const;
+ TDEConfig* config() const;
void init(bool forceLocal);
@@ -39,7 +39,7 @@ class KHighscorePrivate;
* entries.
*
- * You can specify different "keys" for an entry - just like the KConfig
+ * You can specify different "keys" for an entry - just like the TDEConfig
* keys. But it will be prefixed with the number of the entry. For example you
* will probably use something like this to save the name of the player on the
@@ -51,7 +51,7 @@ class KHighscorePrivate;
*
* You can also specify different groups using setHighscoreGroup. Just
- * like the keys mentioned above the groups behave like groups in KConfig
+ * like the keys mentioned above the groups behave like groups in TDEConfig
* but are prefixed with "KHighscore_". The default group is just "KHighscore".
* You might use this e.g. to create different highscore tables like
@@ -164,7 +164,7 @@ public:
* @param entry The number of the entry / the placing of the player
* @param key A key for this entry. E.g. "name" for the name of the
- * player. Nearly the same as the usual keys in KConfig - but they
+ * player. Nearly the same as the usual keys in TDEConfig - but they
* are prefixed with the entry number
* @param value The value of this entry
@@ -179,7 +179,7 @@ public:
* This is an overloaded member function, provided for convenience.
* It differs from the above function only in what argument(s) it accepts.
- * See KConfigBase documentation for allowed TQVariant::Type.
+ * See TDEConfigBase documentation for allowed TQVariant::Type.
**/
void writeEntry(int entry, const TQString& key, const TQVariant &value);
@@ -187,7 +187,7 @@ public:
* @param entry The number of the entry / the placing to be read
* @param key The key of the entry. E.g. "name" for the name of the
- * player. Nearly the same as the usual keys in KConfig - but they
+ * player. Nearly the same as the usual keys in TDEConfig - but they
* are prefixed with the entry number
* @param pDefault This will be used as default value if the key+pair
@@ -200,7 +200,7 @@ public:
* @param entry The number of the entry / the placing to be read
* @param key The key of the entry. E.g. "name" for the name of the
- * player. Nearly the same as the usual keys in KConfig - but they
+ * player. Nearly the same as the usual keys in TDEConfig - but they
* are prefixed with the entry number
* @param pDefault This will be used as default value if the key+pair
@@ -211,7 +211,7 @@ public:
/**
* Read a TQVariant entry.
- * See KConfigBase documentation for allowed TQVariant::Type.
+ * See TDEConfigBase documentation for allowed TQVariant::Type.
*
* @return the value of this entry+key pair or pDefault if the entry+key
@@ -234,7 +234,7 @@ public:
* depends on "1" as the first entry!
* @param key The key of the entry. E.g. "name" for the name of the
- * player. Nearly the same as the usual keys in KConfig - but they
+ * player. Nearly the same as the usual keys in TDEConfig - but they
* are prefixed with the entry number
* @param lastEntry the last entry which will be includes into the list.
@@ -250,7 +250,7 @@ public:
* list.count()
* @param key A key for the entry. E.g. "name" for the name of the
- * player. Nearly the same as the usual keys in KConfig - but they
+ * player. Nearly the same as the usual keys in TDEConfig - but they
* are prefixed with the entry number
* @param list The list of values
@@ -288,17 +288,17 @@ public:
protected:
/**
- * @return A groupname to be used in KConfig. Used internally to
+ * @return A groupname to be used in TDEConfig. Used internally to
* prefix the value from highscoreGroup() with "KHighscore_"
**/
@@ -288,17 +288,17 @@ public:
TQString group() const;
/**
- * @return A pointer to the KConfig object to be used. This is
+ * @return A pointer to the TDEConfig object to be used. This is
* either kapp->config() (default) or a KSimpleConfig object for
* a system-wide highscore file.